import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { html } from "lit-html";
import { withKnobs, text } from "@storybook/addon-knobs";
import CATEGORIES from "../../categories";
import readme from "../../../dist/docs/components/widget-service-calls/readme.md";

<Meta title={CATEGORIES.SUB.WIDGETS + "Service Calls"} />

# Widget Service Calls

This widget shows the status of open service calls with a link to the service call detail page.

<Canvas
    mdxSource={`
    <ui-widget-service-calls
        url="/mock-data/widget-service-calls.json"
    ></ui-widget-service-calls>
`}
>
    <Story
        height="350px"
        name="widget-service-calls"
        parameters={{
            decorators: [withKnobs],
            jest: [
                "widget-service-calls.e2e.ts",
                "widget-service-calls-item.e2e.ts",
            ],
        }}
    >
        {html`
            <ui-widget-service-calls
                url="${text("URL", "/mock-data/widget-service-calls.json")}"
            ></ui-widget-service-calls>
        `}
    </Story>
</Canvas>

## Empty State:

The empty state also includes a button to open a new service call.

<Canvas
    mdxSource={`
    <ui-widget-service-calls
        url="/mock-data/widget-service-calls-empty.json"
    ></ui-widget-service-calls>
`}
>
    <Story
        height="350px"
        name="widget-service-calls empty"
        parameters={{
            jest: ["widget-empty.e2e.ts"],
        }}
    >
        {html`
            <ui-widget-service-calls
                url="/mock-data/widget-service-calls-empty.json"
            ></ui-widget-service-calls>
        `}
    </Story>
</Canvas>

---

## Usage

```
<ui-widget-service-calls url="https://example.com/myapi"></ui-widget-service-calls>
```

# Developer Documentation

<Description markdown={readme} />
